<?php

namespace Litecms\Zingapp\Actions;

use Illuminate\Support\Carbon;
use Illuminate\Support\Str;
use Litepie\Actions\Concerns\AsAction;
use Litepie\Actions\Traits\LogsActions;
use Litepie\Notification\Traits\SendNotification;
use Litecms\Zingapp\Models\Cuisine;


class CuisineAction
{
    use AsAction;
    use LogsActions;
    use SendNotification;

    private $model;

    public function handle(string $action, Cuisine $cuisine, array $request = [])
    {
        $this->model = $cuisine;

        $function = Str::camel($action);
        event('litecms.zingapp.cuisine.action.' . $action . 'ing', [$cuisine]);
        $data =  $this->$function($cuisine, $request);
        event('litecms.zingapp.cuisine.action.' . $action . 'ed', [$cuisine]);

        $this->logsAction();
        $this->notify();
        return $data;
    }


    public function store(array $request, Cuisine $cuisine)
    {
        $attributes = $request;
        $attributes['user_id'] = user_id();
        $attributes['user_type'] = user_type();
        $cuisine = $cuisine->create($attributes);
        return $cuisine;
    }

    public function update(array $request, Cuisine $cuisine)
    {
        $attributes = $request;
        $cuisine->update($attributes);
        return $cuisine;
    }

    public function delete(array $request, Cuisine $cuisine)
    {
        $cuisine->delete();
        return $cuisine;
    }

    public function copy(array $request, Cuisine $cuisine)
    {
        $count = $request['count'] ?: 1;

        if ($count == 1) {
            $cuisine = $cuisine->replicate();
            $cuisine->created_at = Carbon::now();
            $cuisine->save();
            return $cuisine;
        }

        for ($i = 1; $i <= $count; $i++) {
            $new = $cuisine->replicate();
            $new->created_at = Carbon::now();
            $new->save();
        }

        return $cuisine;
    }


}
