<?php

namespace Litecms\Zingapp\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Litecms\Zingapp\Http\Resources\ZingappResource;
use Litecms\Zingapp\Http\Resources\ZingappsCollection;
use Litecms\Zingapp\Scopes\CuisinePublicScope;
use Litecms\Zingapp\Models\Cuisine;

class CuisinePublicController extends BaseController
{

    /**
     * Show cuisine's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Cuisine::pushScope(new RequestScope())
            ->pushScope(new CuisinePublicScope())
            ->select('cuisines.*')
            ->paginate($pageLimit)
            ->withQueryString();

        $data = new CuisinesCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('zingapp::cuisine.names'))
            ->view('zingapp::public.cuisine.index')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show cuisine.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = Cuisine::findBySlug($slug);
        $data = new CuisineResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('zingapp::cuisine.name'))
            ->view('zingapp::public.cuisine.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
